Displaying 20 results from an estimated 8539 matches for "decoded".
Did you mean:
decided
2007 Nov 12
0
2 commits - libswfdec/swfdec_loadvars_as.c test/trace
libswfdec/swfdec_loadvars_as.c | 2 -
test/trace/Makefile.am | 9 ++++++
test/trace/loadvars-decode-5.swf |binary
test/trace/loadvars-decode-5.swf.trace | 23 +++++++++++++++
test/trace/loadvars-decode-6.swf |binary
test/trace/loadvars-decode-6.swf.trace | 23 +++++++++++++++
test/trace/loadvars-decode-7.swf |binary
2004 Sep 10
2
better seeking
When I was trying to find yesterday's xmms-plugin bug, i have noticed
that seeking in stream without seek-table isn't very good. With
attached patch it is much better.
--
Miroslav Lichvar
-------------- next part --------------
diff --git a/libswfdec/swfdec_audio_stream.c b/libswfdec/swfdec_audio_stream.c
index b2c7fd3..b03ef14 100644
--- a/libswfdec/swfdec_audio_stream.c
+++ b/libswfdec/swfdec_audio_stream.c
@@ -38,10 +38,8 @@ swfdec_audio_stream_dispose (GObject *ob
SwfdecAudioStream *stream = SWFDEC_...
2005 Jan 25
0
bitbuffer optimizations
On Mon, Jan 24, 2005 at 06:31:21PM -0800, Josh Coalson wrote:
> yes, a mere 2 years later it is checked in!
>
> speed improvement for me is roughly 17% testing flac files on
> linux-i386.
Thanks!
In case you would like to check another old patch, I have attached updated
patch for seekable stream decoder, originally posted on 09/07/2003.
--- src/libFLAC/seekable_stream_decoder.c.orig 2003-02-26 19:41:51.000000000 +0100
+++ src/libFLAC/seekable_stream_decoder.c 2003-07-09 23:49:35.000000000 +0200
2004 Sep 10
3
Altivec, automake
I think I've gotten FLAC__lpc_restore_signal() about as good as I'm going to
get it.
Here's what I have:
-a new file, lpc_asm.s, which has the assembly routines
-changes to cpu.h, cpu.c, and stream_decoder.c to enable them
-changes to configure.in to support the new cpu stuff
-a preliminary Makefile.am
-maybe something else I'm forgetting
Now automake complains that configure.in
2004 Sep 10
2
Altivec, automake
Here's what I listed in that email. Merging doesn't appear to be necessary. If
you have any build problems, let me know.
Note that my detection code is Darwin-specific. It's a BSD call (sysctl()), so
a change to the platform-detection macros should enable it to work on other
BSDs. However, I don't know what that would be, and I couldn't determine any
safe way to do the check
2006 Oct 28
3
better seeking
...ke it
to CVS, so here is another try.
I made some benchmarking with the test_seeking utility from flac
sources to show how bad the current seeking is, especially without
seektable. Track used for the experiment had about 50 minutes.
In the following table is average number of seeks and number of
decoded frames required for one complete absolute seek. I tried
several files encoded with fixed/variable block size, seektable with
seekpoints every 10s, 100s and no seektable.
unpatched patched
block size seek decoded decoded
points seeks frames seeks frames
fixed
10s 1.22 2.04 1.16 1.83...
2011 Dec 23
2
Decoding only a certain frame results in different values than when decoding the entire file
My file is 3 hours long, so decoding takes around 5 minutes on an
average computer.
That is a bit too long unfortunately...
Am 23.12.2011 20:38, schrieb Steve Checkoway:
> On Dec 23, 2011, at 10:54, Hermann Weber<hermie.weber at gmx.de> wrote:
>
>> And how many frames does Speex need to "recover"?
>> Or is that not predictable?
> No idea. My guess is not
2007 Nov 12
0
3 commits - libswfdec/swfdec_player.c test/trace
libswfdec/swfdec_player.c | 18 +--
test/trace/loadvars-decode-5.swf |binary
test/trace/loadvars-decode-5.swf.trace | 182 +++++++++++++++++++++++++++++++++
test/trace/loadvars-decode-6.swf |binary
test/trace/loadvars-decode-6.swf.trace | 182 +++++++++++++++++++++++++++++++++
test/trace/loadvars-decode-7.swf |binary
test/trace/loadvars-decode-7.swf.trace |
2004 Sep 10
0
Linking against libFLAC_static.lib using MSVC
I'm having a hell of a time linking against libFLAC_static.lib on Win32:
link -out:blib\arch\auto\Audio\FLAC\Decoder\Decoder.dll -dll -nologo -nodefaultlib -debug -opt:ref,icf -libpath:"C:\Perl\lib\CORE" -machine:x86 Decoder.obj libflacsupport.lib C:\Perl\lib\CORE\perl58.lib C:\Perl\lib\CORE\libFLAC_static.lib -def:Decoder.def
Creating library
2007 Apr 08
0
6 commits - libswfdec/Makefile.am libswfdec/swfdec_audio_flv.c libswfdec/swfdec_audio_flv.h libswfdec/swfdec_audio_stream.c libswfdec/swfdec_audio_stream.h libswfdec/swfdec_buffer.c libswfdec/swfdec_codec_adpcm.c libswfdec/swfdec_codec_audio.c
...equest from */
- guint playback_skip; /* number of samples to skip at start of queue */
+ guint next_timestamp; /* next timestamp in FLV file we request from */
+ guint playback_skip; /* number of samples to skip at start of queue */
GQueue * playback_queue; /* all the samples we've decoded so far */
};
--
Miroslav Lichvar
-------------- next
2016 Feb 09
2
Compilation failure using mingw-w64 and gcc-5.3.0
Thank you for the feedback.
This is cross-compiling for mingw-w64-x86_64 using gcc-5.3.0 and
mingw-w64-4.0.4 on GNU/Linux.
Upon attempting to compile now, a large number of errors occur in
flac/decode.c which I have placed at the end of this email. They are eased
by adding this to decode.c:
#if _WIN32
#include <windows.h>
#include <shlobj.h>
#endif
...among the headers.
Then, this
2007 Apr 06
0
3 commits - libswfdec-gtk/swfdec_gtk_loader.c libswfdec/Makefile.am libswfdec/swfdec_codec.c libswfdec/swfdec_codec_ffmpeg.c libswfdec/swfdec_codec_gst.c libswfdec/swfdec_codec.h libswfdec/swfdec_codec_screen.c libswfdec/swfdec_codec_video.c
...fdec_debug.h"
typedef struct _SwfdecCodecScreen SwfdecCodecScreen;
struct _SwfdecCodecScreen {
+ SwfdecVideoDecoder decoder; /* the decoder */
gulong width; /* width of last image */
gulong height; /* height of last image */
SwfdecBuffer * buffer; /* buffer containing last decoded image */
};
-static gpointer
-swfdec_codec_screen_init (SwfdecVideoFormat type)
-{
- SwfdecCodecScreen *screen = g_new0 (SwfdecCodecScreen, 1);
-
- return screen;
-}
-
-static gboolean
-swfdec_codec_screen_get_size (gpointer codec_data,
- guint *width, guint *height)
-{
- SwfdecCodecScreen...
2006 Nov 03
2
better seeking
...t_frame_sample && pos < last_pos) {
- /* our last move backwards wasn't big enough, double it */
- pos -= (last_pos - pos);
- needs_seek = true;
+ this_frame_sample = decoder->private_->last_frame.header.number.sample_number;
+
+ if (!decoder->private_->samples_decoded || (this_frame_sample + decoder->private_->last_frame.header.blocksize >= upper_bound_sample && !first_seek)) {
+ if (pos == (FLAC__int64)lower_bound || !needs_seek) {
+ decoder->protected_->state = FLAC__STREAM_DECODER_SEEK_ERROR;
+ return false;
}
- else {
-...
2007 Dec 21
1
Continous decoding of several audio files without destroying speex_decoder
Hi All,
We are using speex decoder only for narrow band decoding.
Quite often, even though source frame is not silence, decoded audio is
silence.
I wonder there is a problem in the way we uses speex decoder API.
Basically, we initialize speex decoder only once and just reset the decoder
before we decoding another file.
Do we need to intialize speex decoder and destory decoder for each audio
file decoding ?
Here is current...
2005 Jun 20
1
NB decode in SB
...ixed point version the signal generated from the narrowband
decode is downshifted at the end. In this same version the wideband
then upshifts the signal by the same amount.
I would like to do away with the downshift on the narrowband side and
the upshift on the wideband side and just past the decoded signal
through. To do this and allow for the decoding of narrowband only
signals I need to detect who the calling function is to the narrowband
decode.
What I was wondering is if there was already a member variable that held
the current decode state.
-Fritz
Jean-Marc Valin wrote:
>Coul...
2014 Dec 15
1
[PATCH] src/libFLAC/stream_decoder.c : Rework fix for seeking bug.
To avoid crash caused by an unbound LPC decoding when predictor order is
larger than blocksize, the sanity check needs to be moved to the subframe
decoding functions.
---
src/libFLAC/stream_decoder.c | 30 ++++++++++++------------------
1 file changed, 12 insertions(+), 18 deletions(-)
diff --git a/src/libFLAC/stream_decoder.c b/src/libFLAC/stream_decoder.c
index d13b23b..211b4db 100644
---
2013 Jul 01
2
About Decode Streaming
Sorry, I am newbie.
Sample codes are from
https://github.com/oneman/libflac/tree/master/examples/cpp.
I used FLAC__stream_decoder_process_single function but it still gives
exception. Maybe I could not control read callback, you're right.
I will check it and write result in this thread.
Thanks for help.
2013/7/1 Martijn van Beurden <mvanb1 at gmail.com>
> I'll top-post this
2005 Sep 27
4
Speex ver 1.1.10 decoder problem
Hi,
I just started using speex recently and I've been
having problem with Speex ver. 1.1.10 decoder. I used
Speex to encode a wav file to spx then decode it back
to wav file to see the voice quality that results from
different speex options. Somehow, I couldn't get the
original wav file back. I used both Speex ver 1.1.6
and ver 1.1.10 to both encode and decode, despite the
same output
2006 Dec 05
2
intro + specification remarks + some questions
...der decode / 7.2.2.1. packet decode
it is quite confusing for a newbie that 7.2.2.1 is a subsection of 7.2.2
as it is *not* the logical "next step" when decoding the header. Packet
decode should really have a line saying something like: "when decoding
an audio packet, the floor is decoded as follows". This goes for both
floors and residues.
* it would be interesting to note the size of vectors in the pseudocode.
Some parts of the pseudocode become unusable without this information:
a particular example from "8.6.2. packet decode": "allocate and zero all
vecto...
2011 Dec 21
3
Decoding only a certain frame results in different values than when decoding the entire file
...s there anything special
> that I have to keep in mind?
>
> I thought that I could simply read the bytes from the encoded
file for
> example from the start position of the 2nd frame and then decode
it. I
> did that, and I can play it play, but the values in the decoded 2nd
> frame are different than they are when I decode the entire file
and then
> look at the values for the 2nd frame.
> I hope I could explain it well.
>
> I noticed that there is a pattern in the beginning of the encoded
file,
> and I am not sure if I...